Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(733)

Unified Diff: runtime/vm/object.h

Issue 2796993002: Rename dart::Genericity::kClass to dart::Genericity::kCurrentClass to avoid (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/flow_graph_builder.cc ('k') | runtime/vm/object.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.h
diff --git a/runtime/vm/object.h b/runtime/vm/object.h
index 87fbd6cb11f2ca986907302e46e36f7174f826ce..a41c6ffa7b712f3382da07300c193f462bb4ab49 100644
--- a/runtime/vm/object.h
+++ b/runtime/vm/object.h
@@ -1556,8 +1556,8 @@ class UnresolvedClass : public Object {
// Classification of type genericity according to type parameter owners.
enum Genericity {
- kAny, // Consider type params of class and functions.
- kClass, // Consider type params of class only.
+ kAny, // Consider type params of current class and functions.
+ kCurrentClass, // Consider type params of current class only.
kFunctions, // Consider type params of current and parent functions.
kCurrentFunction, // Consider type params of current function only.
kParentFunctions // Consider type params of parent functions only.
« no previous file with comments | « runtime/vm/flow_graph_builder.cc ('k') | runtime/vm/object.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698